# Contributing to vtap100

Be excellent to each other!

All contributions are under the [MIT License](LICENSE).

Do not use material protected by copyright, patents or similar, only your very own work.

## We love contributions

When contributing to this repository, please first discuss the change you wish to make via issue, with the core contributors of this repository before making a change.

We encourage you to contribute to this project.
Contributing is possible by i.e.:
- spreading the word about this package
- reporting issues
- proposing changes/improvements to the documentation
- fixing issues
- improving tests
- proposing/discussing features
- implementing features

## Reporting issues

Issues are reported at the [packages issue tracker at Github](https://github.com/jensens/vtap100/issues).

Please search for existing issues on GitHub before reporting new ones.
This approach minimizes duplicates, streamlines issue management, and saves time for both reporters and maintainers.

Use the issue template addressing your problem.

## Pull Requests

First check if someone else already created a pull request solving your problem.
If so, get in contact with the author(s) and coordinate with them.

If you're the first, fork the repository and work on the code.
We recommend to create a branch in the fork too in order to make it easier to update the base branch.

Create a draft pull request after the first commit and mark it as draft.
This way you communicate your work to other developers, reducing the risk of duplicate work,

While working on the pull request ensure to run tests and linter before each commit and push.

If work is ready, remove the draft status from the PR to signalize readiness for review.

On of the core contributors will review, comment and - if all is fine - merge it.

## Documentation

We love improvements to the documentation.

Follow the pull request path also for documentation changes.

## Coding Agents/ AI

It is OK to use coding agents.
The project was developed with assistence of Claude Code (Opus 4.5).
CLAUDE.md defines the base criteria an agent should use as initial seed prompt.
Just do not believe in code or documentation created by agents, as a human control it.
State in commits which coding agent was used.
Do not create PRs without prior review.
We will reject any rubbish PRs created by agents.
